Learn R Programming

SLqPCR (version 1.38.0)

geomMean: Geometric Mean

Description

Computation of the geometric mean.

Usage

geomMean(x, na.rm = FALSE)

Arguments

x
numeric vector of non-negative Reals
na.rm
a logical value indicating whether NA values should be stripped before the computation proceeds.

Value

geometric mean

Details

The computation of the geometric mean is done via prod(x)^(1/length(x)).